@@ -282,4 +282,13 @@ def test_bframe_iter():
     for k,v in bframe:
         iterCount += 1
 
-    assert iterCount == bframe.dims[0]
\ No newline at end of file
+    assert iterCount == bframe.dims[0]
+
+def test_slice_empty_obj():
+    bframe = BiocFrame({}, numberOfRows=100)
+    assert bframe is not None
+
+    sliced_bframe = bframe[10:30, :]
+    assert sliced_bframe is not None
+
+    assert sliced_bframe.shape == (20, 0)
\ No newline at end of file
